@@ -51,7 +51,7 @@ def load_xl_db(db_file, flatten=False, squash=False, data_only=False, string_onl
     for sheet in sheets:
         sheet_name = wb[sheet].title
         workbook_dict.update({sheet_name: {}})
-        for table in wb[sheet]._tables:
+        for table in wb[sheet].tables.values():
 
             if flatten:
                 if squash:
@@ -212,7 +212,7 @@ def add_schema_table_to_worksheet(_work_sheet, name, schema, data=None, table_st
         last_data_row = _add_table_data(_work_sheet, column_headers, data, schema=schema, dv_dict=dv_dict,
                                         col_offset=col_offset)
     else:
-        data = [{"fillRow": True}]
+        data = _fill_row_data(schema)
         last_data_row = _add_table_data(_work_sheet, column_headers, data, schema=schema, dv_dict=dv_dict,
                                         col_offset=col_offset)
 
@@ -343,6 +343,19 @@ def _add_table_data(_work_sheet, headers, data, schema=None, dv_dict=None, col_o
     return _last_row_idx
 
 
+def _fill_row_data(_schema):
+    _fill_row = {}
+    if 'properties' in _schema.keys():
+        for key, value in _schema['properties'].items():
+            if 'default' in value.keys():
+                _fill_row.update({key: value['default']})
+
+    if(len(_fill_row.keys())) == 0:
+        _fill_row = {"fillRow": True}
+
+    return [_fill_row]
+
+
 def _validate_data(_schema, _data):
 
     for _row in _data:
@@ -367,7 +380,7 @@ def _create_enum_dv(values, allow_blank=True):
     values = [x for x in values if x is not None]
     # Stringify values and create data-validation object
     _values = '"{}"'.format(','.join(values))
-    dv = DataValidation(type="list", formula1=_values, allow_blank=allow_blank)
+    dv = DataValidation(type="list", formula1=_values, allow_blank=allow_blank, errorStyle='warning')
 
     # Optionally set a custom error message
     dv.error = 'Entry not in the list'
@@ -379,7 +392,7 @@ def _create_enum_dv(values, allow_blank=True):
 def _create_tref_dv(_tref, allow_blank=True):
 
     # Stringify values and create data-validation object
-    dv = DataValidation(type="list", formula1=_tref, allow_blank=allow_blank)
+    dv = DataValidation(type="list", formula1=_tref, allow_blank=allow_blank, errorStyle='warning')
 
     # Optionally set a custom error message
     dv.error = 'Entry not in the list'
